@@ -376,6 +376,7 @@ FPp.needsParens = function(assumeExpressionContext) {
       return true;
 
     case "CallExpression":
+    case "NewExpression":
       return name === "callee"
         && parent.callee === node;
 
@@ -392,10 +393,13 @@ FPp.needsParens = function(assumeExpressionContext) {
     }
 
   case "ArrowFunctionExpression":
-    if(n.CallExpression.check(parent) && name === 'callee') {
+    if (n.CallExpression.check(parent) &&
+        name === 'callee') {
       return true;
     }
-    if(n.MemberExpression.check(parent) && name === 'object') {
+
+    if (n.MemberExpression.check(parent) &&
+        name === 'object') {
       return true;
     }
 
@@ -406,6 +410,7 @@ FPp.needsParens = function(assumeExpressionContext) {
         name === "body") {
       return true;
     }
+
     break;
 
   case "CallExpression":
@@ -527,6 +532,12 @@ FPp.firstInStatement = function() {
       return true;
     }
 
+    if (n.AssignmentExpression.check(parent) &&
+        childName === "left") {
+      assert.strictEqual(parent.left, child);
+      return true;
+    }
+
     if (n.SequenceExpression.check(parent) &&
         parentName === "expressions" &&
         childName === 0) {
